function [perf_mean, perf_var] = MVMC_tune(data, C1_list, C2_list, params)
% This code is for 2 view by default
% it could be easily extended for more views
    X1 = data.X1;
    X2 = data.X2;
    Y = data.Y;
    [~,d1] = size(X1); 
    [n,d2] = size(X2);
    r = length(unique(Y));  % number of clusters

    k = 100;    % pre-defined parameter indicating the k largest singular vector
    [Z1,P1,V1] = lansvd(X1,min(k,d1));
    [Z2,P2,V2] = lansvd(X2,min(k,d2));

    Whole_iter = 10; % conduct the experiments 10 times
    PERF_cell = cell(1,Whole_iter);
    for iter = 1:Whole_iter
        disp(['This is the ',num2str(iter),'-th times.']);
        perf = [];
        % generate the side information 
        omega=zeros(n,n);
        Q = triu(ones(n,n),1);
        p = find(Q==1);
        temp = randperm(length(p),params.numPair);
        omega(p(temp))=1;
        omega = omega+omega';
        U=zeros(n,r);
        for i=1:n
            U(i,Y(i))=1;
        end
        % ground-truth similarity matrix
        S_tr = U*U';  
        % sampling observed similarity matrix
        S_ob = S_tr.*omega; 
        for i = 1:length(C1_list)
            params.C1 = C1_list(i);
            for j = 1:length(C2_list)
                params.C2 = C2_list(j);
                disp(['When C1 = ',num2str(params.C1),' and C2 = ', num2str(params.C2),':']);    
                clustering; % for simplicity
                perf = [perf;[iter,params.C1,params.C2,Fscore,Precision,...
                    Recall,NMI,AR,Entro]];
            end
        end
        PERF_cell{iter} = perf;
    end
    perf_mean = mean(cat(3,PERF_cell{:}),3);
    perf_var = std(cat(3,PERF_cell{:}),0,3);
    perf_mean(:,1) = [];
    perf_var(:,1) = [];